<?php

use hitb\core\recipe\DefaultRecipeService;
use hitb\core\resource\DefaultResourceService;
use hitb\core\security\DefaultAuthenticationService;
use hitb\core\user\DefaultUserService;
use hitb\core\user\FileUserRepository;
use hitb\facades\recipe\converter\RecipeConverter;
use hitb\facades\user\converter\ReverseUserConverter;
use hitb\facades\user\converter\UserConverter;
use Phalcon\Db\Adapter\Pdo\Mysql;
use Phalcon\DI\FactoryDefault;
use Phalcon\Mvc\Dispatcher;
use Phalcon\Mvc\Url;
use Phalcon\Mvc\View;
use Phalcon\Mvc\View\Engine\Volt;
use Phalcon\Session\Adapter\Files;

// Create a DI
$di = new FactoryDefault();

$di->set('security', function(){
	$security = new Phalcon\Security();
	//Set the password hashing factor to 11 rounds
	$security->setWorkFactor(11);
	return $security;
}, true);

// Sessions
$di->set('sessionService', function() {
	$session = new Files();
	$session->start();

	return $session;
});

// Resources
$di->set('resourceService', function() {
	return new DefaultResourceService();
});

// Users
$di->set('userConverter', function() {
	return new UserConverter();
});

$di->set('reverseUserConverter', function() {
	return new ReverseUserConverter();
});

$di->set('authenticationService', function() use ($di) {
	$auth = new DefaultAuthenticationService();
	$auth->setSecurity($di->get('security'));
	return $auth;
});

$di->set('userService', function() {
	return new DefaultUserService();
});

$di->set('userFacade', array(
	"className" => "hitb\\facades\\user\\DefaultUserFacade",
	"calls" => array(
		array(
			"method" => "setAuthenticationService",
			"arguments" => array(
				array('type' => 'service', 'name' => 'authenticationService')
			)
		),
		array(
			"method" => "setSessionService",
			"arguments" => array(
				array('type' => 'service', 'name' => 'sessionService')
			)
		),
		array(
			"method" => "setUserConverter",
			"arguments" => array(
				array('type' => 'service', 'name' => 'userConverter')
			)
		),
		array(
			"method" => "setReverseUserConverter",
			"arguments" => array(
				array('type' => 'service', 'name' => 'reverseUserConverter')
			)
		),
		array(
			"method" => "setUserService",
			"arguments" => array(
				array('type' => 'service', 'name' => 'userService')
			)
		),
		array(
			"method" => "setSecurity",
			"arguments" => array(
				array('type' => 'service', 'name' => 'security')
			)
		)
	)
));

// Recipes
$di->set('recipeConverter', function() use ($di) {
	$recipeConverter = new RecipeConverter();
	$recipeConverter->setUserFacade($di->get('userFacade'));
	return $recipeConverter;
});

$di->set('recipeService', function() use ($di) {
	return new DefaultRecipeService();
});

$di->set('recipeFacade', array(
	"className" => "hitb\\facades\\recipe\\DefaultRecipeFacade",
	"calls" => array(
		array(
			"method" => "setRecipeService",
			"arguments" => array(
				array('type' => 'service', 'name' => 'recipeService')
			)
		),
		array(
			"method" => "setRecipeConverter",
			"arguments" => array(
				array('type' => 'service', 'name' => 'recipeConverter')
			)
		)
	)
));

// Setup the database service
$di->set('db', function() use ($config) {
	return new Mysql(array(
		"host" => $config->database->host,
		"username" => $config->database->username,
		"password" => $config->database->password,
		"dbname" => $config->database->name
	));
});

// Register Volt view engine
$di->set('voltService', function($view, $di) {
	$volt = new Volt($view, $di);
	$volt->setOptions(array(
		"compiledPath" => "../app/storefront/cache/compiled-templates/",
		"compiledExtension" => ".compiled",
		"compiledSeparator" => "__",
		"compileAlways" => true
	));

	return $volt;
});

// Setup the dispatcher
$di->set('dispatcher', function() {
	$dispatcher = new Dispatcher();
	$dispatcher->setDefaultNamespace('hitb\storefront\controllers\\');

	return $dispatcher;
});

// Setup the view component
$di->set('view', function() {
	$view = new View();
	$view->setViewsDir('../app/storefront/views/');
	$view->registerEngines(array(
		".volt" => "voltService"
	));

	return $view;
});

// Setup a base URI so that all generated URIs include the "tutorial" folder
//$di->set('url', function() {
//	$url = new Url();
//	$url->setBaseUri('/tutorial/');
//
//	return $url;
//});

