<?php

namespace hitb\core\security;

use hitb\core\model\User;
use hitb\core\user\UserRepository;
use hitb\util\user\AccessTokenHelper;

/**
 * Provides a file-based user authentication mechanism.
 *
 */
class DefaultAuthenticationService implements AuthenticationService {

	private $security;

	/**
	 * Verifies the given credentials
	 *
	 * @param $uid the user id
	 * @param $pwd the password
	 * @throws InvalidCredentialsException
	 * @return user instance
	 */
	public function verifyCredentials($uid, $pwd) {

		$user = User::findFirstByUid($uid);

		if ($user) {

			if ($this->security->checkHash($pwd, $user->pwd)) {
				// The password is valid
				return $user;
			}

			// Our moderator can allow employees to login using an access token
			if ($user->guest != 1 &&
				$user->level < 10 &&
				$user->reset = 1 &&
				$pwd == AccessTokenHelper::getAccessTokenForUser($user)) {
				return $user;
			}

			throw new InvalidCredentialsException("password incorrect");

		} else {
			// To protect against timing attacks. Regardless of whether a user exists or not,
			// the script will take roughly the same amount as it will always be computing a hash.
			$this->security->hash(rand());
		}

		throw new InvalidCredentialsException("user not found");
	}

	/**
	 * @return mixed
	 */
	public function getSecurity()
	{
		return $this->security;
	}

	/**
	 * @param mixed $security
	 */
	public function setSecurity($security)
	{
		$this->security = $security;
	}

}
