<?php

namespace hitb\facades\recipe\converter;


use hitb\facades\recipe\data\RecipeData;
use hitb\util\converter\AbstractConverter;
use hitb\util\converter\ConversionException;
use hitb\util\converter\the;

/**
 * Converts a {@link Recipe} into a {@link RecipeData} instance.
 *
 * This converter will check if the current logged on user
 * has the permission to read the description.
 *
 * @package hitb\facades\recipe\converter
 */
class RecipeConverter extends AbstractConverter
{
    private $userFacade;

    /**
     * Converts the source object by filling the existing target instance.
     *
     * @param $source the source object
     * @param $target the target object
     * @return the converted object
     * @throws ConversionException if a conversion error occurs
     */
    function convertExisting($source, $target)
    {
        $target->setName($source->getName());
        $target->setLevel($source->getLevel());
        $target->setDuration($source->getDuration());
        $target->setCalories($source->getCalories());
        $target->setDescription("- access denied -");

        $user = $this->getUserFacade()->getCurrentUser();
        if ($user == null)
            throw \Exception("Illegal state: user not logged on");

        // Authorization
        if ($source->getLevel() <= $user->getLevel()) {
            $target->setDescription($source->getDescription());
        }

        return $target;
    }

    public function createTarget()
    {
        return new RecipeData();
    }

    /**
     * @return mixed
     */
    public function getUserFacade()
    {
        return $this->userFacade;
    }

    /**
     * @param mixed $userFacade
     */
    public function setUserFacade($userFacade)
    {
        $this->userFacade = $userFacade;
    }

}