<?php

namespace hitb\facades\user;

/**
 * Interface that provides access to users.
 */
interface UserFacade {

	/**
	 * Retrieves the currently logged in user, if any.
	 *
	 * @return 
	 */
	function getCurrentUser();

	/*
	 * Refreshes the currently logged in user.
	 */
	function refreshCurrentUser();

	/**
	 * Checks the given credentials and creates a session for the user.
	 *
	 * @throws InvalidCredentialsException
	 * @return 
	 */
	function login($uid, $pwd);

	/**
	 * Removes the session for the current user.
	 *
	 */
	function logout();

	/**
	 * Retrieves a list of employees.
	 *
	 * @return mixed
	 */
	function getEmployees();

	/**
	 * Creates a new guest user.
	 *
	 * @param $guest
	 * @return mixed
	 * @throws \Exception
	 */
	function createGuestUser($guest, $pwd);

	/**
	 * Updates the profile of the guest user.
	 *
	 * @param $guest
	 * @return mixed
	 * @throws \Exception
	 */
	function updateGuestUser($guest);

}

