<?php

namespace hitb\storefront\forms;
use hitb\util\forms\Form;


/**
 * Represents a user form and provides all necessary validation.
 *
 * @package hitb\storefront\forms
 */
class UserForm extends Form
{
    private $uid;
    private $level;
    private $reset;
    private $restaurant;

    /**
     * Populates the current form instance based on the given request data.
     *
     * @param $request
     */
    public function populate($request) {

        if ($request->getPost("uid") != null)
            $this->setUid($request->getPost("uid"));

        if ($request->getPost("level") != null)
            $this->setLevel($request->getPost("level"));

        if ($request->getPost("reset") != null)
            $this->setReset($request->getPost("reset"));

        if ($request->getPost("restaurant") != null)
            $this->setRestaurant($request->getPost("restaurant"));
    }

    /**
     * @return mixed
     */
    public function getUid()
    {
        return $this->uid;
    }

    /**
     * @param mixed $uid
     */
    public function setUid($uid)
    {
        if (empty($uid)) {
            $this->addValidationConstraint('uid', 'empty', 'uid is required');
        }
        if (strlen($uid) < 6) {
            $this->addValidationConstraint('uid', 'length', 'uid must be at least 6 chars long');
        }
        if (strlen($uid) >= 70) {
            $this->addValidationConstraint('uid', 'length', 'uid can only be 70 chars long');
        }
        if (!preg_match('/^[a-z0-9]+$/', $uid)) {
            $this->addValidationConstraint('uid', 'format', 'uid can only contain lowercase chars a-z and numbers');
        }

        $this->uid = $uid;
    }

    /**
     * @return mixed
     */
    public function getLevel()
    {
        return $this->level;
    }

    /**
     * @param mixed $level
     */
    public function setLevel($level)
    {
        $value = (int) $level;
        if (!($value > 0 && $value <= 10)) {
            $this->addValidationConstraint('level', 'invalid', 'level must be between 1 and 10');
        }

        $this->level = $level;
    }

    /**
     * @return mixed
     */
    public function getReset()
    {
        return $this->reset;
    }

    /**
     * @param mixed $reset
     */
    public function setReset($reset)
    {
        $value = (int) $reset;
        if (!$value == 0 && !$value == 1) {
            $this->addValidationConstraint('reset', 'invalid', 'reset must be either 0 or 1');
        }

        $this->reset = $reset;
    }

    /**
     * @return mixed
     */
    public function getRestaurant()
    {
        return $this->restaurant;
    }

    /**
     * @param mixed $restaurant
     */
    public function setRestaurant($restaurant)
    {
        if (strlen($restaurant) >= 70) {
            $this->addValidationConstraint('restaurant', 'length', 'uid can only be 70 chars long');
        }
        if (!preg_match('/^[a-zA-Z ]+$/', $restaurant)) {
            $this->addValidationConstraint('restaurant', 'format', 'uid can only contain chars a-z and space');
        }
        $this->restaurant = $restaurant;
    }

}